@@ -29,6 +29,7 @@ from .cv.models.diffusion import ldm as _ldm
 from .cv.models.diffusion import ldm_vq as _ldm_vq
 from .cv.models.diffusion import ldm_sd as _ldm_sd
 from .cv.models.diffusion import ldm_sd_v2 as _ldm_sd_v2
+from .cv.models.diffusion import ldm_sd_v2_base as _ldm_sd_v2_base
 from .cv.models.diffusion import ldm_sr as _ldm_sr
 from .cv.models.diffusion import ldm_sd_anime as _ldm_sd_anime
 from .cv.models.diffusion import ldm_semantic as _ldm_semantic
@@ -1367,6 +1368,10 @@ def ldm_sd_v2(pretrained: bool = True) -> DLPipeline:
     return _ldm_sd_v2(pretrained)
 
 
+def ldm_sd_v2_base(pretrained: bool = True) -> DLPipeline:
+    return _ldm_sd_v2_base(pretrained)
+
+
 def ldm_celeba_hq(pretrained: bool = True) -> DLPipeline:
     return _ldm_celeba_hq(pretrained)
 
