@@ -4,6 +4,7 @@ import numpy as np
 import torch.nn as nn
 
 from abc import abstractmethod
+from abc import ABC
 from abc import ABCMeta
 from torch import Tensor
 from typing import Any
@@ -33,31 +34,20 @@ from ...modules.blocks import MixedStackedEncoder
 
 
 NUMERICAL_KEY = "_numerical"
+CATEGORICAL_INDICES_KEY = "_categorical_indices"
 ONE_HOT_KEY = "_one_hot"
 EMBEDDING_KEY = "_embedding"
 MERGED_KEY = "_merged"
 ml_core_dict: Dict[str, Type["IMLCore"]] = {}
 
 
-class IEncoder:
-    merged_dim: int
-    merged_dims: Dict[int, int]
-    one_hot_dim: int
-    embedding_dim: int
-
-    def __call__(self, *args: Any, **kwds: Any) -> Any:
-        pass
-
-    def encode(self, *args: Any, **kwds: Any) -> Any:
-        pass
-
-
 class EncodingResult(NamedTuple):
-    one_hot: Optional[torch.Tensor]
-    embedding: Optional[torch.Tensor]
+    indices: Optional[Tensor]
+    one_hot: Optional[Tensor]
+    embedding: Optional[Tensor]
 
     @property
-    def merged(self) -> torch.Tensor:
+    def merged(self) -> Tensor:
         if self.one_hot is None and self.embedding is None:
             raise ValueError("no data is provided in `EncodingResult`")
         if self.one_hot is None:
@@ -69,6 +59,21 @@ class EncodingResult(NamedTuple):
         return torch.cat([self.one_hot, self.embedding], dim=-1)
 
 
+class IEncoder(ABC):
+    merged_dim: int
+    merged_dims: Dict[int, int]
+    one_hot_dim: int
+    embedding_dim: int
+
+    @abstractmethod
+    def __call__(self, *args: Any, **kwds: Any) -> EncodingResult:
+        pass
+
+    @abstractmethod
+    def encode(self, *args: Any, **kwds: Any) -> EncodingResult:
+        pass
+
+
 class SplitFeatures(NamedTuple):
     categorical: Optional[EncodingResult]
     numerical: Optional[Tensor]
@@ -441,6 +446,7 @@ class MLModel(ModelWithCustomSteps):
             else:
                 b[ONE_HOT_KEY] = split.categorical.one_hot
                 b[EMBEDDING_KEY] = split.categorical.embedding
+                b[CATEGORICAL_INDICES_KEY] = split.categorical.indices
             b[MERGED_KEY] = transform(split)
 
         if self._num_repeat is None:
@@ -463,7 +469,7 @@ class MLModel(ModelWithCustomSteps):
                 local_batch = shallow_copy_dict(batch)
                 _inject_batch(local_batch, batch_indices, d, t)
                 batches.append(local_batch)
-        all_results: Dict[str, List[torch.Tensor]] = {}
+        all_results: Dict[str, List[Tensor]] = {}
         for m, m_batch in zip(self.core, batches):  # type: ignore
             m_kwargs = shallow_copy_dict(kwargs)
             sub_results = m(batch_idx, m_batch, state, **m_kwargs)
