@@ -254,13 +254,9 @@ def _get_d(inp: Union[str, tensor_dict_type]) -> tensor_dict_type:
     return shallow_copy_dict(inp)
 
 
-def convert(
+def _get_inp(
     inp: Union[str, tensor_dict_type],
-    api: DiffusionAPI,
-    *,
-    vae_inp: Optional[Union[str, tensor_dict_type]] = None,
-    load: bool = False,
-    use_mapping: bool = True,
+    vae_inp: Optional[Union[str, tensor_dict_type]],
 ) -> tensor_dict_type:
     inp = _get_d(inp)
     if vae_inp is not None:
@@ -272,6 +268,18 @@ def convert(
                 inp[inp_k] = v
                 num_injected += 1
         print(f">> injected vae parameters: {num_injected}")
+    return inp
+
+
+def convert(
+    inp: Union[str, tensor_dict_type],
+    api: DiffusionAPI,
+    *,
+    vae_inp: Optional[Union[str, tensor_dict_type]] = None,
+    load: bool = False,
+    use_mapping: bool = True,
+) -> tensor_dict_type:
+    inp = _get_inp(inp, vae_inp)
     with api.load_context() as wrapper:
         md = wrapper.state_dict()
         if not use_mapping:
@@ -283,6 +291,40 @@ def convert(
     return nd
 
 
+def convert_v2(
+    inp: Union[str, tensor_dict_type],
+    api: DiffusionAPI,
+    *,
+    vae_inp: Optional[Union[str, tensor_dict_type]] = None,
+    load: bool = False,
+) -> tensor_dict_type:
+    inp = _get_inp(inp, vae_inp)
+    for k in [
+        "log_one_minus_alphas_cumprod",
+        "sqrt_recip_alphas_cumprod",
+        "sqrt_recipm1_alphas_cumprod",
+    ]:
+        inp.pop(k)
+    with api.load_context() as wrapper:
+        md = wrapper.state_dict()
+        nd = {}
+        for k in [
+            "core.condition_model.m.text_projection.bias",
+            "core.condition_model.m.text_transformer.attention_mask",
+        ]:
+            nd[k] = md.pop(k)
+        with open(download_static("sd_v2_mapping", extension="json"), "r") as f:
+            mapping = json.load(f)
+        for k, mk in mapping.items():
+            v = inp[k]
+            if mk == "core.condition_model.m.text_projection.weight":
+                v = v.t()
+            nd[mk] = v.view(md[mk].shape)
+        if load:
+            wrapper.load_state_dict(nd)
+    return nd
+
+
 def inject(inp: Union[str, tensor_dict_type], api: DiffusionAPI) -> None:
     d = _get_d(inp)
     with api.load_context() as wrapper:
@@ -291,5 +333,6 @@ def inject(inp: Union[str, tensor_dict_type], api: DiffusionAPI) -> None:
 
 __all__ = [
     "convert",
+    "convert_v2",
     "inject",
 ]
